var indexSectionsWithContent =
{
  0: "abcdefghilmoprstuvw",
  1: "cdim"
};

var indexSectionNames =
{
  0: "all",
  1: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Pages"
};

